==> artemis_ui_kit-0.0.2.tar.gz: lib/src/ArtemisRadioButton.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';

import 'Consts.dart';

class ArtemisRadioButton extends StatelessWidget {
  final bool value;
  final ValueChanged<dynamic> onChanged;
  final String label;
  final Widget? labelWidget;
  final bool disabled;
  final bool loading;
  final EdgeInsetsGeometry? padding;
  final Color? activeColor;

  const ArtemisRadioButton(
      {Key? key,
      this.padding,
      this.loading = false,
      required this.value,
      required this.onChanged,
      this.label = "",
      this.labelWidget,
      this.activeColor,
      this.disabled = false})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
      style: TextButton.styleFrom(padding: padding ?? EdgeInsets.all(4)),
      onPressed: disabled
          ? null
          : () {
              onChanged(!value);
            },
      child: Row(
        children: [
          SizedBox(
              width: 20,
              height: 20,
              child: Radio(
                  activeColor: disabled
                      ? ArtemisColors.brownGrey.withOpacity(0.8)
                      : value
                          ? (activeColor?? ArtemisColors.primary)
                          : ArtemisColors.brownGrey5,
                  value: value,
                  groupValue: true,
                  onChanged: (v) {
                    if (!disabled) {
                      onChanged(v);
                    }
                  })),
          SizedBox(width: 8),
          loading
              ? SpinKitThreeBounce(
                  color: value ? ArtemisColors.lightIshBlue : ArtemisColors.black,
                  size: 24,
                )
              :labelWidget?? Text("$label",
                  style: TextStyle(
                      fontSize: 16,
                      color: disabled
                          ? ArtemisColors.brownGrey.withOpacity(0.8)
                          : value
                              ? (activeColor?? ArtemisColors.primary)
                              : ArtemisColors.texts))
        ],
      ),
    );
  }
}

==> artemis_ui_kit-0.0.16.tar.gz: lib/src/ArtemisRadioButton.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';

import 'Consts.dart';

class ArtemisRadioButton extends StatelessWidget {
  final bool value;
  final ValueChanged<dynamic> onChanged;
  final String label;
  final Widget? labelWidget;
  final bool disabled;
  final bool loading;
  final EdgeInsetsGeometry? padding;
  final Color? activeColor;

  const ArtemisRadioButton(
      {Key? key,
      this.padding,
      this.loading = false,
      required this.value,
      required this.onChanged,
      this.label = "",
      this.labelWidget,
      this.activeColor,
      this.disabled = false})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
      style: TextButton.styleFrom(padding: padding ?? EdgeInsets.all(4)),
      onPressed: disabled
          ? null
          : () {
              onChanged(!value);
            },
      child: Row(
        children: [
          SizedBox(
              width: 20,
              height: 20,
              child: Radio(
                  activeColor: disabled
                      ? ArtemisColors.brownGrey.withOpacity(0.8)
                      : value
                          ? (activeColor ?? ArtemisColors.primary)
                          : ArtemisColors.brownGrey5,
                  value: value,
                  groupValue: true,
                  onChanged: (v) {
                    if (!disabled) {
                      onChanged(v);
                    }
                  })),
          SizedBox(width: 8),
          loading
              ? SpinKitThreeBounce(
                  color:
                      value ? ArtemisColors.lightIshBlue : ArtemisColors.black,
                  size: 24,
                )
              : labelWidget ??
                  Text("$label",
                      style: TextStyle(
                          fontSize: 16,
                          color: disabled
                              ? ArtemisColors.brownGrey.withOpacity(0.8)
                              : value
                                  ? (activeColor ?? ArtemisColors.primary)
                                  : ArtemisColors.texts))
        ],
      ),
    );
  }
}
